"use client";

import useFormSubmission from "@/hooks/use-form-submission";
import { selectDesignType } from "@/servers/actions/pool-request-action";
import { useTranslations } from "next-intl";
import { useRouter } from "next/navigation";
import { Suspense } from "react";
import FormButtons from "../common/form-buttons";
import DesignOptions from "./design-options";
import DesignOptionsSkeleton from "./design-options-skeleton";

// Server action for design selection
async function handleDesignSelect(formData: FormData, messages: { success: string, error: string, missing: string }) {
	const designType = formData.get("designType");

	if (!designType) {
		// Handle error case
		return { success: false, message: messages.missing };
	}

	const response = await selectDesignType({ design_type: designType as string });
	console.log("response: ", response);
	if (response.success) {
		// Return success status instead of showing toast directly
		return { success: true, message: messages.success };
	} else {
		// Handle error case
		return { success: false, message: response.message || messages.error };
	}
}

// Client component to handle toast notifications
function DesignTypeFormClient() {
	const t = useTranslations();
	const router = useRouter();

	const messages = {
		success: t("The design type has been saved successfully"),
		error: t("Failed to save design type"),
		missing: t("Please select a design type")
	};

	const { handleSubmit, handleNextClick, isPending, isNextPending } = useFormSubmission(
		handleDesignSelect,
		messages,
		"/simulation-program/pool-details"
	);

	return (
		<form action={handleSubmit}>
			<div className="border-[1px] rounded-md p-2 w-[800px] backdrop-blur-md">
				<Suspense fallback={<DesignOptionsSkeleton />}>
					<DesignOptions isPending={isPending} />
				</Suspense>
			</div>
			<FormButtons
				onPrevious={() => router.back()}
				onNext={handleNextClick}
				isPending={isNextPending}
			/>
		</form>
	);
}

// Server component that renders the client component
export default function DesignTypeForm() {
	return <DesignTypeFormClient />;
} 